==> ifrit_3.4.2.orig.tar.gz: ifrit-3.4.2/core/ihistogram.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IHISTOGRAM_H
#define IHISTOGRAM_H


#include "ipiecewisefunction.h"


#include "iposition.h"

class iHistogramMaker;


class iHistogram : public iPiecewiseFunction
{
	
	friend class iHistogramMaker;

	IPOINTER_AS_PART(ViewModule);

public:
	
	static iHistogram* New(iViewModule *vm, iHistogramMaker *parent = 0);
	
	inline iHistogramMaker* GetMaker() const { return mParent; }

	int GetStretch() const { return mStretch; }

	float GetMinValue() const { return mValMin; }
	float GetMaxValue() const { return mValMax; }

	vtkIdType GetMinCellIndex() const { return mCellMin; }
	vtkIdType GetMaxCellIndex() const { return mCellMax; }

	const iPosition& GetMinCellPosition() const { return mPosMin; }
	const iPosition& GetMaxCellPosition() const { return mPosMax; }
	
	void Copy(const iHistogram *h);

protected:

	virtual ~iHistogram();

private:

	iHistogram(iViewModule *vm, iHistogramMaker *parent);

	void SetData(int n, float *values);

	iHistogramMaker *mParent;

	float mValMin, mValMax;
	int mStretch;

	//
	//  Properties of the Min and Max cells
	//
	vtkIdType mCellMin, mCellMax;
	iPosition mPosMin, mPosMax;
};

#endif

==> ifrit_4.1.2.orig.tar.gz: ifrit-4.1.2/core/ihistogram.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IHISTOGRAM_H
#define IHISTOGRAM_H


#include "iarray.h"


class iHistogram
{
	
	friend class iHistogramMaker;

public:
	
	static const iHistogram& Null();

	~iHistogram();

	inline int NumBins() const { return mValues.Size(); }
	inline int StretchId() const { return mStretchId; }

	float GetMin() const;
	float GetMax() const;
	void GetRange(float range[2]) const;

	float GetBinMin(int i) const;
	float GetBinMax(int i) const;
	void GetBinRange(int i, float range[2]) const;

	int Bin(float v) const;
	float Value(int i) const;

	//void Copy(const iHistogram &h);

private:

	iHistogram();

	void Clear();
	void Reset(int nbins, float min, float max, int sid);

#ifdef I_CHECK
	void Check() const;
#endif

	int mStretchId;
	float mStretchedMin, mStretchedMax, mValueToBinScale;
	iArray<float> mValues;
	iArray<float> mBins;
};

#endif
